==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/General/lyrics/translations/lyrics_plugin_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>Lyrics</name>
    <message>
        <location filename="../lyrics.cpp" line="35"/>
        <source>View Lyrics</source>
        <translation>Vedi testi lirica</translation>
    </message>
    <message>
        <location filename="../lyrics.cpp" line="36"/>
        <source>Ctrl+L</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LyricsFactory</name>
    <message>
        <location filename="../lyricsfactory.cpp" line="29"/>
        <source>Lyrics Plugin</source>
        <translation>Modulo Lirica</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="50"/>
        <source>About Lyrics Plugin</source>
        <translation>Info sul modulo Lirica</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="51"/>
        <source>Qmmp Lyrics Plugin</source>
        <translation>Modulo Lirica per Qmmp</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="53"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autore: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="52"/>
        <source>This plugin retrieves lyrics from lyricsplugin.com</source>
        <translation>Modulo che permette di trovare testi di canzoni da lyricsplugin.com</translation>
    </message>
</context>
<context>
    <name>LyricsWindow</name>
    <message>
        <location filename="../lyricswindow.cpp" line="113"/>
        <source>Lyrics: %1 - %2</source>
        <translation>Testo: %1 - %2</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="88"/>
        <location filename="../lyricswindow.ui" line="67"/>
        <source>No connection</source>
        <translation>Nessuna connessione</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="75"/>
        <source>Not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="91"/>
        <source>Looking up host...</source>
        <translation>Ricerca host</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="94"/>
        <source>Connecting...</source>
        <translation>Connessione...</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="97"/>
        <source>Sending request...</source>
        <translation>Invio richiesta...</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="100"/>
        <source>Receiving</source>
        <translation>Ricezione</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="103"/>
        <source>Connected</source>
        <translation>Connesso</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="106"/>
        <source>Closing connection...</source>
        <translation>Chiusura connessione...</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="14"/>
        <source>Lyrics Plugin</source>
        <translation>Modulo Lirica</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="31"/>
        <source>Artist:</source>
        <translation>Artista:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="41"/>
        <source>Title:</source>
        <translation>Titolo:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="51"/>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="87"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
</context>
</TS>

==> qmmp_0.4.3.orig.tar.gz: qmmp-0.4.3/src/plugins/General/lyrics/translations/lyrics_plugin_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>Lyrics</name>
    <message>
        <location filename="../lyrics.cpp" line="35"/>
        <source>View Lyrics</source>
        <translation>Vedi testi lirica</translation>
    </message>
    <message>
        <location filename="../lyrics.cpp" line="36"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
</context>
<context>
    <name>LyricsFactory</name>
    <message>
        <location filename="../lyricsfactory.cpp" line="29"/>
        <source>Lyrics Plugin</source>
        <translation>Modulo Lirica</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="50"/>
        <source>About Lyrics Plugin</source>
        <translation>Info sul modulo Lirica</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="51"/>
        <source>Qmmp Lyrics Plugin</source>
        <translation>Modulo Lirica per Qmmp</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="53"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autore: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="52"/>
        <source>This plugin retrieves lyrics from lyricsplugin.com</source>
        <translation>Modulo che permette di trovare testi di canzoni da lyricsplugin.com</translation>
    </message>
</context>
<context>
    <name>LyricsWindow</name>
    <message>
        <location filename="../lyricswindow.cpp" line="64"/>
        <source>Done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="67"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="127"/>
        <source>Lyrics: %1 - %2</source>
        <translation>Testo: %1 - %2</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="60"/>
        <source>No connection</source>
        <translation>Nessuna connessione</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="115"/>
        <source>Not found</source>
        <translation>Non trovato</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="96"/>
        <location filename="../lyricswindow.cpp" line="126"/>
        <source>Receiving</source>
        <translation>Ricezione</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="14"/>
        <source>Lyrics Plugin</source>
        <translation>Modulo Lirica</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="31"/>
        <source>Artist:</source>
        <translation>Artista:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="41"/>
        <source>Title:</source>
        <translation>Titolo:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="51"/>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
</context>
</TS>
